@@ -73,20 +73,22 @@ Loader.add_constructor('!from_yaml', Loader.from_yaml)
 
 
 def find_config():
-    '''Search up the diretcory hierarchy for .scuba.yml
+    '''Search up the directory hierarchy for .scuba.yml
 
-    Returns: path, rel on success, or None if not found
+    Returns: path, rel, config on success, or None if not found
         path    The absolute path of the directory where .scuba.yml was found
         rel     The relative path from the directory where .scuba.yml was found
                 to the current directory
+        config  The loaded configuration
     '''
     cross_fs = 'SCUBA_DISCOVERY_ACROSS_FILESYSTEM' in os.environ
     path = os.getcwd()
 
     rel = ''
     while True:
-        if os.path.exists(os.path.join(path, SCUBA_YML)):
-            return path, rel
+        cfg_path = os.path.join(path, SCUBA_YML)
+        if os.path.exists(cfg_path):
+            return path, rel, load_config(cfg_path)
 
         if not cross_fs and os.path.ismount(path):
             msg = '{} not found here or any parent up to mount point {}'.format(SCUBA_YML, path) \
